# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61uth_service.proto\"/\n\x0cLoginRequest\x12\r\n\x05login\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"d\n\rLoginResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\r\x12\x12\n\ntoken_type\x18\x04 \x01(\t\",\n\x13RefreshTokenRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"k\n\x14RefreshTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\r\x12\x12\n\ntoken_type\x18\x04 \x01(\t\"%\n\rLogoutRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"\x10\n\x0eLogoutResponse\"*\n\x12LogoutOtherRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"\x15\n\x13LogoutOtherResponse\"C\n\x19UpdateUserPasswordRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x1c\n\x1aUpdateUserPasswordResponse\"=\n\x16UpdateUserEmailRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"\x19\n\x17UpdateUserEmailResponse\")\n\x11\x43heckTokenRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"G\n\x12\x43heckTokenResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_user_id\"1\n\x18\x43heckServiceTokenRequest\x12\x15\n\rservice_token\x18\x01 \x01(\t\",\n\x19\x43heckServiceTokenResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xe0\x03\n\x04\x41uth\x12&\n\x05Login\x12\r.LoginRequest\x1a\x0e.LoginResponse\x12;\n\x0cRefreshToken\x12\x14.RefreshTokenRequest\x1a\x15.RefreshTokenResponse\x12)\n\x06Logout\x12\x0e.LogoutRequest\x1a\x0f.LogoutResponse\x12\x38\n\x0bLogoutOther\x12\x13.LogoutOtherRequest\x1a\x14.LogoutOtherResponse\x12I\n\x0eUpdatePassword\x12\x1a.UpdateUserPasswordRequest\x1a\x1b.UpdateUserPasswordResponse\x12@\n\x0bUpdateEmail\x12\x17.UpdateUserEmailRequest\x1a\x18.UpdateUserEmailResponse\x12\x35\n\nCheckToken\x12\x12.CheckTokenRequest\x1a\x13.CheckTokenResponse\x12J\n\x11\x43heckServiceToken\x12\x19.CheckServiceTokenRequest\x1a\x1a.CheckServiceTokenResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOGINREQUEST._serialized_start=22
  _LOGINREQUEST._serialized_end=69
  _LOGINRESPONSE._serialized_start=71
  _LOGINRESPONSE._serialized_end=171
  _REFRESHTOKENREQUEST._serialized_start=173
  _REFRESHTOKENREQUEST._serialized_end=217
  _REFRESHTOKENRESPONSE._serialized_start=219
  _REFRESHTOKENRESPONSE._serialized_end=326
  _LOGOUTREQUEST._serialized_start=328
  _LOGOUTREQUEST._serialized_end=365
  _LOGOUTRESPONSE._serialized_start=367
  _LOGOUTRESPONSE._serialized_end=383
  _LOGOUTOTHERREQUEST._serialized_start=385
  _LOGOUTOTHERREQUEST._serialized_end=427
  _LOGOUTOTHERRESPONSE._serialized_start=429
  _LOGOUTOTHERRESPONSE._serialized_end=450
  _UPDATEUSERPASSWORDREQUEST._serialized_start=452
  _UPDATEUSERPASSWORDREQUEST._serialized_end=519
  _UPDATEUSERPASSWORDRESPONSE._serialized_start=521
  _UPDATEUSERPASSWORDRESPONSE._serialized_end=549
  _UPDATEUSEREMAILREQUEST._serialized_start=551
  _UPDATEUSEREMAILREQUEST._serialized_end=612
  _UPDATEUSEREMAILRESPONSE._serialized_start=614
  _UPDATEUSEREMAILRESPONSE._serialized_end=639
  _CHECKTOKENREQUEST._serialized_start=641
  _CHECKTOKENREQUEST._serialized_end=682
  _CHECKTOKENRESPONSE._serialized_start=684
  _CHECKTOKENRESPONSE._serialized_end=755
  _CHECKSERVICETOKENREQUEST._serialized_start=757
  _CHECKSERVICETOKENREQUEST._serialized_end=806
  _CHECKSERVICETOKENRESPONSE._serialized_start=808
  _CHECKSERVICETOKENRESPONSE._serialized_end=852
  _AUTH._serialized_start=855
  _AUTH._serialized_end=1335
# @@protoc_insertion_point(module_scope)
