# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_info_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17user_info_service.proto\"?\n\x1aGetNotificationInfoRequest\x12\x15\n\rservice_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"a\n\x1bGetNotificationInfoResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_superuser\x18\x04 \x01(\x08\x32\\\n\x08UserInfo\x12P\n\x13GetNotificationInfo\x12\x1b.GetNotificationInfoRequest\x1a\x1c.GetNotificationInfoResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_info_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETNOTIFICATIONINFOREQUEST._serialized_start=27
  _GETNOTIFICATIONINFOREQUEST._serialized_end=90
  _GETNOTIFICATIONINFORESPONSE._serialized_start=92
  _GETNOTIFICATIONINFORESPONSE._serialized_end=189
  _USERINFO._serialized_start=191
  _USERINFO._serialized_end=283
# @@protoc_insertion_point(module_scope)
