# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: role_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12role_service.proto\"2\n\x0eGetUserRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"C\n\x1b\x41nyUserOAuthProviderAccount\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\t\"\x8b\x01\n\x0fGetUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_superuser\x18\x04 \x01(\x08\x12\x34\n\x0eoauth_accounts\x18\x05 \x03(\x0b\x32\x1c.AnyUserOAuthProviderAccount\"R\n\x12GetUserListRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x13\n\x0bpage_number\x18\x02 \x01(\r\x12\x11\n\tpage_size\x18\x03 \x01(\r\"P\n\nUserInList\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_superuser\x18\x04 \x01(\x08\"\xa9\x01\n\x13GetUserListResponse\x12\x1c\n\x07results\x18\x01 \x03(\x0b\x32\x0b.UserInList\x12\x13\n\x0btotal_count\x18\x02 \x01(\r\x12\x13\n\x0btotal_pages\x18\x03 \x01(\r\x12\x16\n\tprev_page\x18\x04 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tnext_page\x18\x05 \x01(\rH\x01\x88\x01\x01\x42\x0c\n\n_prev_pageB\x0c\n\n_next_page\";\n\x13\x43reatePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x0e\n\x06policy\x18\x02 \x01(\t\"\"\n\x14\x43reatePolicyResponse\x12\n\n\x02id\x18\x01 \x01(\t\"G\n\x13UpdatePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06policy\x18\x03 \x01(\t\"\x16\n\x14UpdatePolicyResponse\"7\n\x13\x44\x65letePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\x16\n\x14\x44\x65letePolicyResponse\"4\n\x10GetPolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"#\n\x11GetPolicyResponse\x12\x0e\n\x06policy\x18\x01 \x01(\t\"T\n\x14GetPolicyListRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x13\n\x0bpage_number\x18\x02 \x01(\r\x12\x11\n\tpage_size\x18\x03 \x01(\r\"\x9d\x01\n\x15GetPolicyListResponse\x12\x0e\n\x06policy\x18\x01 \x03(\t\x12\x13\n\x0btotal_count\x18\x02 \x01(\r\x12\x13\n\x0btotal_pages\x18\x03 \x01(\r\x12\x16\n\tprev_page\x18\x04 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tnext_page\x18\x05 \x01(\rH\x01\x88\x01\x01\x42\x0c\n\n_prev_pageB\x0c\n\n_next_page\";\n\x12\x43heckAccessRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x0f\n\x07inquiry\x18\x02 \x01(\t\"K\n\x13\x43heckAccessResponse\x12\x12\n\nhas_access\x18\x01 \x01(\x08\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_user_id2\xd8\x03\n\tAdminRole\x12,\n\x07GetUser\x12\x0f.GetUserRequest\x1a\x10.GetUserResponse\x12\x38\n\x0bGetUserList\x12\x13.GetUserListRequest\x1a\x14.GetUserListResponse\x12;\n\x0c\x43reatePolicy\x12\x14.CreatePolicyRequest\x1a\x15.CreatePolicyResponse\x12;\n\x0cUpdatePolicy\x12\x14.UpdatePolicyRequest\x1a\x15.UpdatePolicyResponse\x12;\n\x0c\x44\x65letePolicy\x12\x14.DeletePolicyRequest\x1a\x15.DeletePolicyResponse\x12\x32\n\tGetPolicy\x12\x11.GetPolicyRequest\x1a\x12.GetPolicyResponse\x12>\n\rGetPolicyList\x12\x15.GetPolicyListRequest\x1a\x16.GetPolicyListResponse\x12\x38\n\x0b\x43heckAccess\x12\x13.CheckAccessRequest\x1a\x14.CheckAccessResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'role_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETUSERREQUEST._serialized_start=22
  _GETUSERREQUEST._serialized_end=72
  _ANYUSEROAUTHPROVIDERACCOUNT._serialized_start=74
  _ANYUSEROAUTHPROVIDERACCOUNT._serialized_end=141
  _GETUSERRESPONSE._serialized_start=144
  _GETUSERRESPONSE._serialized_end=283
  _GETUSERLISTREQUEST._serialized_start=285
  _GETUSERLISTREQUEST._serialized_end=367
  _USERINLIST._serialized_start=369
  _USERINLIST._serialized_end=449
  _GETUSERLISTRESPONSE._serialized_start=452
  _GETUSERLISTRESPONSE._serialized_end=621
  _CREATEPOLICYREQUEST._serialized_start=623
  _CREATEPOLICYREQUEST._serialized_end=682
  _CREATEPOLICYRESPONSE._serialized_start=684
  _CREATEPOLICYRESPONSE._serialized_end=718
  _UPDATEPOLICYREQUEST._serialized_start=720
  _UPDATEPOLICYREQUEST._serialized_end=791
  _UPDATEPOLICYRESPONSE._serialized_start=793
  _UPDATEPOLICYRESPONSE._serialized_end=815
  _DELETEPOLICYREQUEST._serialized_start=817
  _DELETEPOLICYREQUEST._serialized_end=872
  _DELETEPOLICYRESPONSE._serialized_start=874
  _DELETEPOLICYRESPONSE._serialized_end=896
  _GETPOLICYREQUEST._serialized_start=898
  _GETPOLICYREQUEST._serialized_end=950
  _GETPOLICYRESPONSE._serialized_start=952
  _GETPOLICYRESPONSE._serialized_end=987
  _GETPOLICYLISTREQUEST._serialized_start=989
  _GETPOLICYLISTREQUEST._serialized_end=1073
  _GETPOLICYLISTRESPONSE._serialized_start=1076
  _GETPOLICYLISTRESPONSE._serialized_end=1233
  _CHECKACCESSREQUEST._serialized_start=1235
  _CHECKACCESSREQUEST._serialized_end=1294
  _CHECKACCESSRESPONSE._serialized_start=1296
  _CHECKACCESSRESPONSE._serialized_end=1371
  _ADMINROLE._serialized_start=1374
  _ADMINROLE._serialized_end=1846
# @@protoc_insertion_point(module_scope)
